==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/es-CO/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Campos personalizados',
    'manage'                    => 'Gestionar',
    'field'		                => 'Campo',
    'about_fieldsets_title'		=> 'Acerca de los grupos de campos',
    'about_fieldsets_text'		=> 'Los grupos de campos le permiten agrupar campos personalizados que se reutilizan frecuentemente para determinados modelos de activos.',
    'custom_format'             => 'Formato de Regex personalizado...',
    'encrypt_field'      	        => 'Cifrar el valor de este campo en la base de datos',
    'encrypt_field_help'      => 'ADVERTENCIA: Cifrar un campo hace que no se pueda buscar.',
    'encrypted'      	        => 'Cifrado',
    'fieldset'      	        => 'Grupo de campos',
    'qty_fields'      	      => 'Campos de cantidad',
    'fieldsets'      	        => 'Grupo de campos',
    'fieldset_name'           => 'Nombre del grupo de campos',
    'field_name'              => 'Nombre del Campo',
    'field_values'            => 'Valores del Campo',
    'field_values_help'       => 'Añade opciones seleccionables, una por línea. Líneas en blanco además de la primera será ignorada.',
    'field_element'           => 'Elemento de Formulario',
    'field_element_short'     => 'Elemento',
    'field_format'            => 'Formato',
    'field_custom_format'     => 'Formato Regex Personalizado',
    'field_custom_format_help'     => 'Este campo te permite usar una expresión regex para la validación. Este debe empezar con "regex:" - por ejemplo, para validar que un valor de campo personalizado contiene un IMEI válido (15 dígitos numéricos), podrías usar <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Obligatorio',
    'req'   		              => 'Obl.',
    'used_by_models'   		    => 'Usado por los modelos',
    'order'   		            => 'Orden',
    'create_fieldset'         => 'Nuevo grupo de campos',
    'update_fieldset'         => 'Actualizar grupo de campos',
    'fieldset_does_not_exist'   => 'El grupo de campos :id no existe',
    'fieldset_updated'         => 'Se actualizó el grupo de campos',
    'create_fieldset_title' => 'Crear nuevo grupo de campos',
    'create_field'            => 'Nuevo Campo Personalizado',
    'create_field_title' => 'Crear un nuevo campo personalizado',
    'value_encrypted'      	        => 'El valor de este campo está cifrado en la base de datos. Solo los administradores pueden ver el valor descifrado',
    'show_in_email'     => '¿Incluir el campo en los correos de asignación enviados al usuario? Los campos cifrados no se pueden incluir en los correos electrónicos',
    'show_in_email_short'     => 'Incluye en correos electrónicos.',
    'help_text' => 'Texto de ayuda',
    'help_text_description' => 'Este es un texto opcional que aparecerá debajo de los elementos del formulario mientras se edita un activo para proporcionar contexto en el campo.',
    'about_custom_fields_title' => 'Acerca de campos personalizados',
    'about_custom_fields_text' => 'Los campos personalizados le permiten añadir atributos arbitrarios a los activos.',
    'add_field_to_fieldset' => 'Añadir campo al grupo de campos',
    'make_optional' => 'Requerido - haga clic para hacer opcional',
    'make_required' => 'Opcional - haga clic para hacer necesario',
    'reorder' => 'Reordenar',
    'db_field' => 'Campo en base de datos',
    'db_convert_warning' => 'ADVERTENCIA. Este campo está en la tabla de campos personalizados como <code>:db_column</code> pero debe ser <code>:expected</code>.',
    'is_unique' => 'Este valor debe ser único en todos los activos',
    'unique' => 'Único',
    'display_in_user_view' => 'Permitir al usuario ver estos valores en la página "Ver elementos asignados"',
    'display_in_user_view_table' => 'Visible para el usuario',
    'auto_add_to_fieldsets' => 'Añadir automáticamente a cada nuevo grupo de campos',
    'add_to_preexisting_fieldsets' => 'Añadir a cualquier grupo de campos existente',
    'show_in_listview' => 'Mostrar por defecto en las consultas. Los usuarios autorizados podrán mostrar/ocultar a través del selector de columnas',
    'show_in_listview_short' => 'Mostrar en listas',
    'show_in_requestable_list_short' => 'Mostrar en la lista de activos que se pueden solicitar',
    'show_in_requestable_list' => 'Mostrar el valor en la lista de activos que se pueden solicitar. Los campos cifrados no se mostrarán',
    'encrypted_options' => 'Este campo está cifrado, por lo que algunas opciones de visualización no estarán disponibles.',

];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/es-CO/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Campos personalizados',
    'manage'                    => 'Gestionar',
    'field'		                => 'Campo',
    'about_fieldsets_title'		=> 'Acerca de los grupos de campos',
    'about_fieldsets_text'		=> 'Los grupos de campos le permiten agrupar campos personalizados que se reutilizan frecuentemente para determinados modelos de activos.',
    'custom_format'             => 'Formato de Regex personalizado...',
    'encrypt_field'      	        => 'Cifrar el valor de este campo en la base de datos',
    'encrypt_field_help'      => 'ADVERTENCIA: Cifrar un campo hace que no se pueda buscar.',
    'encrypted'      	        => 'Cifrado',
    'fieldset'      	        => 'Grupo de campos',
    'qty_fields'      	      => 'Campos de cantidad',
    'fieldsets'      	        => 'Grupo de campos',
    'fieldset_name'           => 'Nombre del grupo de campos',
    'field_name'              => 'Nombre del Campo',
    'field_values'            => 'Valores del Campo',
    'field_values_help'       => 'Añade opciones seleccionables, una por línea. Líneas en blanco además de la primera será ignorada.',
    'field_element'           => 'Elemento de Formulario',
    'field_element_short'     => 'Elemento',
    'field_format'            => 'Formato',
    'field_custom_format'     => 'Formato Regex Personalizado',
    'field_custom_format_help'     => 'Este campo te permite usar una expresión regex para la validación. Este debe empezar con "regex:" - por ejemplo, para validar que un valor de campo personalizado contiene un IMEI válido (15 dígitos numéricos), podrías usar <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Obligatorio',
    'req'   		              => 'Obl.',
    'used_by_models'   		    => 'Usado por los modelos',
    'order'   		            => 'Orden',
    'create_fieldset'         => 'Nuevo grupo de campos',
    'update_fieldset'         => 'Actualizar grupo de campos',
    'fieldset_does_not_exist'   => 'El grupo de campos :id no existe',
    'fieldset_updated'         => 'Se actualizó el grupo de campos',
    'create_fieldset_title' => 'Crear nuevo grupo de campos',
    'create_field'            => 'Nuevo Campo Personalizado',
    'create_field_title' => 'Crear un nuevo campo personalizado',
    'value_encrypted'      	        => 'El valor de este campo está cifrado en la base de datos. Solo los administradores pueden ver el valor descifrado',
    'show_in_email'     => '¿Incluir el campo en los correos de asignación enviados al usuario? Los campos cifrados no se pueden incluir en los correos electrónicos',
    'show_in_email_short'     => 'Incluye en correos electrónicos.',
    'help_text' => 'Texto de ayuda',
    'help_text_description' => 'Este es un texto opcional que aparecerá debajo de los campos del formulario cuando se edite un activo para proporcionar contexto adicional.',
    'about_custom_fields_title' => 'Acerca de campos personalizados',
    'about_custom_fields_text' => 'Los campos personalizados le permiten añadir atributos arbitrarios a los activos.',
    'add_field_to_fieldset' => 'Añadir campo al grupo de campos',
    'make_optional' => 'Requerido - haga clic para hacerlo opcional',
    'make_required' => 'Opcional - haga clic para hacer necesario',
    'reorder' => 'Reordenar',
    'db_field' => 'Campo en base de datos',
    'db_convert_warning' => 'ADVERTENCIA. Este campo está en la tabla de campos personalizados como <code>:db_column</code> pero debe ser <code>:expected</code>.',
    'is_unique' => 'Este valor debe ser único en todos los activos',
    'unique' => 'Único',
    'display_in_user_view' => 'Permitir al usuario ver estos valores en la página "Ver elementos asignados"',
    'display_in_user_view_table' => 'Visible para el usuario',
    'auto_add_to_fieldsets' => 'Añadir automáticamente a cada nuevo grupo de campos',
    'add_to_preexisting_fieldsets' => 'Añadir a cualquier grupo de campos existente',
    'show_in_listview' => 'Mostrar por defecto en las consultas. Los usuarios autorizados podrán mostrar/ocultar a través del selector de columnas',
    'show_in_listview_short' => 'Mostrar en listas',
    'show_in_requestable_list_short' => 'Mostrar en la lista de activos que se pueden solicitar',
    'show_in_requestable_list' => 'Mostrar el valor en la lista de activos que se pueden solicitar. Los campos cifrados no se mostrarán',
    'encrypted_options' => 'Este campo está cifrado, por lo que algunas opciones de visualización no estarán disponibles.',

];
